#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-4Kx9eT23ci3FFliKKLpQrL
key:                  persistent-test-2.13.1.3-4Kx9eT23ci3FFliKKLpQrL
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  76113ced15f0851b58f0f73574b6142a
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-4Kx9eT23ci3FFliKKLpQrL
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-Ger2uBePW3nE0joHfQHA2C
    aeson-2.2.2.0-Fs8lpfl0CTvIUZfvQfMaj3 base-4.18.2.1
    blaze-html-0.9.2.0-380P0WKAldyG1qcFn1Xnln bytestring-0.11.5.3
    conduit-1.3.6.1-IawtmlNthjMZXB3dQ2hgV containers-0.6.7
    exceptions-0.10.7 hspec-2.11.7-1Z0PDyf0enY3NJ1rrLm1pA
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    http-api-data-0.6.1-4FmZSRAyaEaCYH46bSmgSM
    monad-control-1.0.3.1-3eTNzQ8ZalcE593nCtkvEJ
    monad-logger-0.3.42-4n9fhybQc0EFWsev7xwuM6 mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.6.0-8Esb4Et8pzqJJLgJVlrxHF
    quickcheck-instances-0.3.33-Gm2TbiER9RrBdFWPbs36VN
    random-1.2.1.3-Ed9sqfiGJWrIk2dDIiP5zT
    resourcet-1.3.0-AF2iyKp8v5N69ibPjX54Ky text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-5pTLlHqIE20LNI8Tt1t4xM
    unliftio-0.2.25.1-4NwnNs4RtDwK8DYnc6XyDt
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-DZIhPqSL0N2YNV8fYQEJ8

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

